# INSTALLATION
###### From main source:
```
git clone https://github.com/structuralbioinformatics/MODPIN.git

cd MODPIN

IF YOU PREFER TO INSTALL IT INSIDE THE FOLDER DOWNLOADED FROME GITHUB:
pip install -e . --user

OR LET PIP INSTALL IT IN THE DEFAULT DIRECTORY 
pip install . --user

```



###### From Pypi:
```
pip install modpin --user
```

###### Configuration
In ORDER TO CONFIGURE THE config.ini file (in modpin/scripts/)  RUN FROM TERMINAL:
```
configuration
```

OR run the script "config_setup.py" in modpin folder.

OR edit directly the config.ini file specifing the paths
